@@ -1,6 +1,6 @@
 /*
  * AJD4JP
- * Copyright (c) 2011-2017  Akira Terasaki
+ * Copyright (c) 2011-2019  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -12,7 +12,7 @@ import java.util.*;
 
 
 /**
- * ユリウス通日および現在一般的に使われているグレゴリオ暦での１日を表します。
+ * ユリウス通日および現在一般的に使われているグレゴリオ暦での１日を表します。<br>全てのコンストラクタはミリ秒情報を切り捨てます。
  */
 public class AJD implements Day {
 	private static final long serialVersionUID = 1;
@@ -40,7 +40,7 @@ public class AJD implements Day {
 	 * @return ミリ秒。
 	 */
 	public long getTime() {
-		return Calc.up( Calc.mul( Calc.mul( Calc.mul( Calc.mul( ajd.subtract( EPOCH ), 24 ), 60 ), 60 ), 1000 ) );
+		return Calc.up( Calc.mul( Calc.mul( Calc.mul( Calc.mul( ajd.subtract( EPOCH ), 24 ), 60 ), 60 ), 1000 ) ) / 1000 * 1000;
 	}
 
 	/**
@@ -170,7 +170,7 @@ public class AJD implements Day {
 	 * @param date 日時。
 	 */
 	public AJD( java.util.Date date ) {
-		this( Calc.mul( Calc.MSEC, date.getTime() ).add( EPOCH ) );
+		this(date, Calc.JP_H);
 	}
 	/**
 	 * コンストラクタ。引数の日時を表すインスタンスを生成します。
@@ -178,7 +178,26 @@ public class AJD implements Day {
 	 * @param offset UTCからの時差(日数)。
 	 */
 	protected AJD( java.util.Date date, BigDecimal offset ) {
-		this( Calc.mul( Calc.MSEC, date.getTime() ).add( EPOCH ), offset );
+		int min = Calc.mul(offset, 24 * 60).intValue();
+		int hour = min / 60;
+		min = min % 60;
+		String gmt = "GMT";
+		if (hour >= 0 && min >= 0) { gmt = String.format("GMT+%02d%02d", hour, min); }
+		else { gmt = String.format("GMT-%02d%02d", hour * -1, min * -1); }
+		Calendar calendar = Calendar.getInstance(TimeZone.getTimeZone(gmt));
+		calendar.setTime(date);
+		try {
+			initAJD(
+				calendar.get(Calendar.YEAR),
+				calendar.get(Calendar.MONTH) + 1,
+				calendar.get(Calendar.DATE),
+				calendar.get(Calendar.HOUR_OF_DAY),
+				calendar.get(Calendar.MINUTE),
+				calendar.get(Calendar.SECOND),
+				offset
+			);
+		}
+		catch(AJDException e){}
 	}
 
 	/**
