@@ -1,6 +1,6 @@
 /*
  * AJD4JP
- * Copyright (c) 2011  Akira Terasaki
+ * Copyright (c) 2011-2017  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -19,12 +19,13 @@ import java.math.*;
  * 特に春分と秋分は日本での祝日にあたり、年によりその日が異なります。
  * 国立天文台の情報に基づき毎年閣議決定されていますが、天文学上の春分・秋分点と
  * 同日を必ずしも祝日に決定するわけではありません。
- * しかし、それ以外の日を祝日とした例は今のところありません(2011年現在)。<br>
+ * しかし、それ以外の日を祝日とした例は今のところありません(2016年現在)。<br>
  * {@link Holiday}は、このクラスの演算結果を元に、春分の日と秋分の日を
  * 決定しています。<br>
  * {@link LunisolarYear}は、このクラスの演算結果を元に旧暦を生成します。<br>
  * {@link STCD}は、このクラスの演算結果を元に生成されます。
 <TABLE border="1">
+<caption>黄経と二十四節季</caption>
   <TBODY>
     <TR>
       <TH>黄経</TH>
@@ -37,12 +38,12 @@ import java.math.*;
       <TH>名称</TH>
     </TR>
     <TR>
-      <TD align="right" bgcolor="#ffff00">0</TD>
-      <TD bgcolor="#ffff00">春分</TD>
+      <TD align="right" style="background-color:#ffff00;">0</TD>
+      <TD style="background-color:#ffff00;">春分</TD>
       <TD align="right">90</TD>
       <TD>夏至</TD>
-      <TD align="right" bgcolor="#ffff00">180</TD>
-      <TD bgcolor="#ffff00">秋分</TD>
+      <TD align="right" style="background-color:#ffff00;">180</TD>
+      <TD style="background-color:#ffff00;">秋分</TD>
       <TD align="right">270</TD>
       <TD>冬至</TD>
     </TR>
@@ -238,6 +239,7 @@ public class Equinox {
 	 * @param yyyy 西暦年。0を指定すると例外が発生します。
 	 * @param ang 太陽黄経。単位は度。
 	 * @return 日時。
+	 * @throws AJDException 不正な年。
 	 */
 	public static AJD getAJD( int yyyy, Angle ang ) throws AJDException {
 		return getAJD( yyyy, ang.convert( Angle.Unit.DEGREE ).getTop() );
@@ -248,6 +250,7 @@ public class Equinox {
 	 * @param yyyy 西暦年。0を指定すると例外が発生します。
 	 * @param ang 太陽黄経。単位は度。
 	 * @return 日時。
+	 * @throws AJDException 不正な年。
 	 */
 	public static AJD getAJD( int yyyy, Number ang) throws AJDException {
 		AJD.check( yyyy, 1 );
@@ -405,6 +408,7 @@ public class Equinox {
 	 * 月相0の時間を含む日が、旧暦での朔日(ついたち＝月の１日目)にあたります。<br>
 	 * また、月相は海の潮汐の指標になります。以下の表はその一例です。
 <table>
+<caption>月相と潮汐</caption>
   <tbody>
     <tr>
       <th colspan="3">月相</th>
