@@ -1,6 +1,6 @@
 /*
  * AJD4JP
- * Copyright (c) 2011  Akira Terasaki
+ * Copyright (c) 2011-2015  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -58,7 +58,7 @@ public enum Week implements OffProvider.Off {
 	 * @return 曜日。
 	 */
 	public static Week get( Day date ) {
-		return values()[(int)(Calc.cut( date.getAJD() ) + 2) % 7];
+		return values()[(int)(Calc.cut( date.toAJD().trim().getAJD() ) + 2) % 7];
 	}
 
 	int get() { return no; }
