@@ -1,6 +1,6 @@
 /*
  * AJD4JP
- * Copyright (c) 2011  Akira Terasaki
+ * Copyright (c) 2011-2015  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -36,6 +36,25 @@ public class Formats extends Format {
 		DATE, new C( " " ), TIME
 	);
 
+	/**
+	 * YYYYMMDD フォーマット。
+	 */
+	public static final Formats YMD = new Formats(
+		new GregorianYearF(), new MonthF(), new DayF()
+	);
+	/**
+	 * HHMMSS 24時間制フォーマット。
+	 */
+	public static final Formats HMS = new Formats(
+		new HourF(), new MinuteF(), new SecondF()
+	);
+	/**
+	 * YYYYMMDDHHMMSS 24時間制フォーマット。
+	 */
+	public static final Formats YMDHMS = new Formats(
+		YMD, HMS
+	);
+
 	/**
 	 * コンストラクタ。
 	 * @param format 出力対象。
