@@ -1,6 +1,6 @@
 /*
  * AJD4JP
- * Copyright (c) 2011  Akira Terasaki
+ * Copyright (c) 2011-2019  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -13,7 +13,7 @@ import ajd4jp.*;
  */
 public class JapaneseYearF extends Format {
 	/**
-	 * 年号の付与。
+	 * 元号の付与。
 	 */
 	public enum Era {
 		/**
@@ -33,7 +33,7 @@ public class JapaneseYearF extends Format {
 	private Era	e;
 	/**
 	 * コンストラクタ。
-	 * @param era 年号の指定。
+	 * @param era 元号の指定。
 	 * @param num 数値表記。
 	 */
 	public JapaneseYearF( Era era, Two num ) {
@@ -66,48 +66,8 @@ public class JapaneseYearF extends Format {
 	String getHead() {
 		String	h = "";
 		ajd4jp.Era	era = jp.getEra();
-		if ( era != null ) {
-			switch( e ) {
-			case KANJI:
-				h = era.getName();
-				break;
-			case FULL:
-				switch( era ) {
-				case MEIJI:
-					h = "Ｍ";
-					break;
-				case TAISHO:
-					h = "Ｔ";
-					break;
-				case SHOWA:
-					h = "Ｓ";
-					break;
-				case HEISEI:
-					h = "Ｈ";
-					break;
-				}
-				break;
-			case HALF:
-				switch( era ) {
-				case MEIJI:
-					h = "M";
-					break;
-				case TAISHO:
-					h = "T";
-					break;
-				case SHOWA:
-					h = "S";
-					break;
-				case HEISEI:
-					h = "H";
-					break;
-				}
-				break;
-			}
-		}
+		if ( era != null ) { h = era.getName(e); }
 		return h;
 	}
-
 }
 
-
