@@ -1,6 +1,6 @@
 /*
  * AJD4JP
- * Copyright (c) 2011-2012  Akira Terasaki
+ * Copyright (c) 2011-2017  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -14,9 +14,9 @@ package ajd4jp;
 public class Version {
 	private Version(){}
 	private static final String VERSION = "@@@ver";
-	private static final String	SITE = "(http://ajd4jp.sourceforge.jp/)";
+	private static final String	SITE = "(http://ajd4jp.osdn.jp/)";
 	private static final String TITLE = "AJD4JP " + VERSION + SITE;
-	private static final String COPY = "Copyright 2011-2012 @@@auth";
+	private static final String COPY = "Copyright 2011-2017 @@@auth";
 
 	/**
 	 * バージョン番号の取得。
